
## Your Definition
[TO BE WRITTEN: Note that this is a sample that does NOTHING. DO NOT use it]

### Node Capabilities
- [TO BE WRITTEN: Note that this is a sample that does NOTHING. DO NOT use it]
- [List the capabilities this node should have]
- [Each capability should be listed in a separate line]

## prompt
[prompt]

## goal
[goal]

## Task
1. Accept the input as [prompt] and [goal].
2. Analyze the [prompt] within the context of the [goal].
3. Perform your specific task based on your capabilities and the given [prompt] and [goal].
4. Output your task result in the [MEDIUM_OUTPUT] section.
5. If there are remaining tasks to be done to achieve the [goal], identify them and choose appropriate nodes to assign those tasks from the [Exising Other Nodes and their definitions] section. Put the results in the [SEND_TO_NODES] section.
6. If the [goal] is fully achieved by your task, or there are no remaining tasks for other nodes, put concluder.md and pass your results in the [SEND_TO_NODES] section. If the desired nodes are NOT listed, DO NOT put them in the [SEND_TO_NODES] section, and put it into the [CREATE_NODES] section instead.
7. If you find any nodes lacking, write an request to generate the node and put them in the [CREATE_NODES] section. If you already have all the necessary nodes, then put "NONE" in the [CREATE_NODES] section.

## Exising Other Nodes and their definitions
[TO BE EMBEDDED]

## Output format
You must always follow the output format below. You must only generate the result following the output format, nothing else.
```
## Goal
{echo your final goal}

## MEDIUM_OUTPUT
{Describe your medium output}

## SEND_TO_NODES
- [target_node.md] -p "[task prompt, organized in a markdown manner, with the summary of the medium output]" -g "[final goal]"
{List up all the nodes to assign the tasks}

## CREATE_NODES
- [suggested_name.md] -d "[node definition prompt, organized in a markdown manner]" -p "[task prompt, organized in a markdown manner]" -g "[final goal]"
{List up all the necessary nodes}
```